@@ -73,9 +73,9 @@ def _log(msg, application, level, execution_time, user_id, extra_data):
 
     if str(config("AGENT")).lower() == "kafka":
         try:
-            obj_producer.poll(0)
             obj_producer.produce(config("TOPIC"), json.dumps(data), callback=acknowledge_err)
-            obj_producer.flush()
+            obj_producer.poll(0)
+            # obj_producer.flush()
         except Exception as e:
             print(e)
             file_logger(data)
